# Copyright (C) 2020-2022 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"

def get_uc_image(d):
    if d.getVar('MACHINE') == "s32g274asbc":
        return "sja1110_flash_image_20201201.bin"
    else:
        return "sja1110_rev3_m2_flash_image.bin"

SJA1110_UC_FW = "${@get_uc_image(d)}"

SJA1110_FW_REV = "1.0.7"

SRC_URI += "file://sja1110_flash_image_20201201.bin"
SRC_URI += "file://sja1110_uc_2g5.${SJA1110_FW_REV}.bin"
SRC_URI += "file://sja1110_uc_m2.${SJA1110_FW_REV}.bin"
SRC_URI += "file://ReleaseNotes-microsys.md"

COMPATIBLE_MACHINE_append = "|s32g274asbc3|s32g274asbc2|s32g274asbc|s32g274acpcis"

do_compile[depends] += "virtual/kernel:do_deploy"

module_do_install_append() {
    install -d ${D}/lib/firmware
    if [ -f "${WORKDIR}/${SJA1110_UC_FW}" ]; then
        cp -f ${WORKDIR}/${SJA1110_UC_FW} ${D}/lib/firmware/sja1110_uc.bin
    fi
    if [ -f "${WORKDIR}/${SJA1110_SWITCH_FW}" ]; then
        cp -f ${WORKDIR}/${SJA1110_SWITCH_FW} ${D}/lib/firmware/sja1110_switch.bin
    fi
    if [ -f "${WORKDIR}/sja1110_flash_image_20201201.bin" ]; then
        cp -f ${WORKDIR}/sja1110_flash_image_20201201.bin ${D}/lib/firmware/sja1110_uc_rev1.bin
    fi
    if [ -f "${WORKDIR}/sja1110_uc_m2.${SJA1110_FW_REV}.bin" ]; then
        cp -f ${WORKDIR}/sja1110_uc_m2.${SJA1110_FW_REV}.bin ${D}/lib/firmware/sja1110_uc_m2.bin
    fi
    if [ -f "${WORKDIR}/sja1110_uc_2g5.${SJA1110_FW_REV}.bin" ]; then
        cp -f ${WORKDIR}/sja1110_uc_2g5.${SJA1110_FW_REV}.bin ${D}/lib/firmware/sja1110_uc_2g5.bin
    fi

    cp -f ${WORKDIR}/ReleaseNotes-microsys.md ${D}/lib/firmware/ReleaseNotes-microsys-sja1110_uc-${SJA1110_FW_REV}.md
}
